@@ -12,9 +12,6 @@ logger = logging.getLogger(__name__)
 
 
 class ArnheimBackendOauth(BaseAuthBackend):
-    failedTries = 5
-    auto_retry = True
-
 
     def __init__(self, config: HerreConfig, **kwargs) -> None:
         super().__init__(config , **kwargs)  
