@@ -42,7 +42,7 @@ class ImplicitApplication(BaseAuthBackend):
         token = None
 
         with GraphicalBackend():
-            assert has_webview, "Please install QtWebEngine if you want to use the Implicit Flow"
+            assert has_webview, "Please install 'PyQtWebEngine' if you want to use the Implicit Flow"
             from bergen.auths.implicit.widgets.login import LoginDialog
             token, accepted = LoginDialog.getToken(backend=self, parent=self.parent)
             
