@@ -1,27 +1,24 @@
 import asyncio
 from abc import ABC, abstractmethod
 from asyncio.futures import Future
-from bergen.messages.postman.unprovide.unprovide_critical import UnprovideCriticalMessage
-from bergen.messages.postman.unprovide import UnprovideDoneMessage, BouncedUnprovideMessage
-from bergen.messages.postman.assign.bounced_cancel_assign import BouncedCancelAssignMessage
-from bergen.messages.postman.assign.bounced_assign import BouncedAssignMessage
-from bergen.messages.postman.provide.provide_done import ProvideDoneMessage
-from bergen.messages.base import MessageModel
-from bergen.messages.postman.provide.bounced_provide import BouncedProvideMessage
+from bergen.handlers.base import Connector
+from bergen.messages import *
 from bergen.hookable.base import Hookable
 import logging
 from typing import Dict, Type
 from bergen.models import Pod
-from .actor import Actor, HostHelper
+from bergen.actors.base import Actor
 from functools import partial
-import uuid
+from bergen.console import console
+
+
 
 logger = logging.getLogger(__name__)
 
+
+
 class BaseEntertainer(Hookable):
     ''' Is a mixin for Our Bergen '''
-    helperClass = None
-
     def __init__(self, raise_exceptions_local=False, client = None, loop=None, **kwargs) -> None:
         super().__init__(**kwargs)
         self.provisions = {}
@@ -29,7 +26,7 @@ class BaseEntertainer(Hookable):
         self.loop = loop or asyncio.get_event_loop()
         self.client = client
 
-        self.hostHelper = self.helperClass(self)
+        self.connector = Connector(self)
 
         self.template_id_actorClass_map: Dict[str, Type[Actor]] = {}
 
@@ -42,6 +39,7 @@ class BaseEntertainer(Hookable):
         self.provide_futures: Dict[str, Future] = {}
 
         self.all_pod_assignments = {}
+        self.all_pod_reservations = {}
 
         self.entertainments = {}
         self.assignments = {}
@@ -58,7 +56,6 @@ class BaseEntertainer(Hookable):
     async def disconnect(self) -> str:
         raise NotImplementedError("Please overwrite")
 
-
     @abstractmethod
     async def activateProvision(self):
          raise NotImplementedError("Please overwrite")
@@ -82,12 +79,11 @@ class BaseEntertainer(Hookable):
         if isinstance(message, UnprovideDoneMessage): 
             # As we send the Activate Provide request to the Platform we will get a Return Statement
             logger.info("Arkitekt acknowledged the deletion of the Pod our our former Actor")
-            self.unprovide_futures[message.meta.reference].set_result(message.data.reference)
+            self.unprovide_futures[message.meta.reference].set_result(message.data)
 
         if isinstance(message, BouncedUnprovideMessage): 
             #  We are responsible To Shut ourselfves down when Arkitekt Tells us t
-            assert message.data.reference is not None, "Received Cancellation with no reference to kill" 
-            logger.info("Arkitekt demands our Actor to die")
+            assert message.data.provision is not None, "Received Cancellation with no reference to kill" 
             self.unentertain(message, from_arkitekt=True)
 
         if isinstance(message, BouncedProvideMessage): 
@@ -96,22 +92,33 @@ class BaseEntertainer(Hookable):
             logger.info("Arkitekt demands a New Actor for us")
             self.entertain(message, from_arkitekt=True)
 
-        
-        if isinstance(message, BouncedAssignMessage):
-            assert message.data.pod is not None, "Received assignation that had no Provision???"
-            assert message.data.pod in self.provision_actor_queue_map, f"Provision not entertained {message.data.pod} {self.provision_actor_queue_map}"
-            await self.provision_actor_queue_map[message.data.pod].put(message)
-            self.all_pod_assignments[message.meta.reference] = message.data.pod # Run in parallel
+        if isinstance(message, BouncedForwardedReserveMessage):
+            logger.info("Arkitekt demands a New Reservation from us")
+            assert message.data.provision is not None, "Received Forwared Reservation that had no Provision???"
+            assert message.data.provision in self.provision_actor_queue_map, f"Provision not entertained {message.data.provision} {self.provision_actor_queue_map}"
+            await self.provision_actor_queue_map[message.data.provision].put(message)
+            self.all_pod_reservations[message.meta.reference] = message.data.provision # Run in parallel
 
-        if isinstance(message, BouncedCancelAssignMessage):
-            if message.data.reference in self.all_pod_assignments: 
+        if isinstance(message, BouncedUnreserveMessage):
+            if message.data.reservation in self.all_pod_reservations: 
+                logger.info("Cancellation for Reservatoion received. Canceling!")
+                hosting_provising = self.all_pod_reservations[message.data.reservation]
+                await self.provision_actor_queue_map[hosting_provising].put(message)
+            else:
+                logger.error("Received Cancellation for task that was not in our tasks..")
+
+
+        if isinstance(message, BouncedForwardedAssignMessage):
+            assert message.data.provision is not None, "Received assignation that had no Provision???"
+            assert message.data.provision in self.provision_actor_queue_map, f"Provision not entertained {message.data.provision} {self.provision_actor_queue_map}"
+            await self.provision_actor_queue_map[message.data.provision].put(message)
+            self.all_pod_assignments[message.meta.reference] = message.data.provision # Run in parallel
+
+        if isinstance(message, BouncedUnassignMessage):
+            if message.data.assignation in self.all_pod_assignments: 
                 logger.info("Cancellation for task received. Canceling!")
-                task = self.assignments[message.data.reference]
-                if not task.done():
-                    task.cancel()
-                    logger.warn("Canceled Task!!")
-                else:
-                    logger.warn("Task had already finished")
+                hosting_provising = self.all_pod_assignments[message.data.assignation]
+                await self.provision_actor_queue_map[hosting_provising].put(message)
             else:
                 logger.error("Received Cancellation for task that was not in our tasks..")
 
@@ -155,12 +162,6 @@ class BaseEntertainer(Hookable):
         if from_arkitekt: logger.info("Cancellation invoked by Arkitekt")
 
         provision_reference = bounced_unprovide.data.provision
-        
-        actor = self.provision_actor_map[provision_reference]
-        
-        # Try to unreserve all reserve resources
-        ok = await actor._on_unprovide() 
-    
         deactivation_task = asyncio.create_task(self.deactivateProvision(bounced_unprovide))
         deactivation_task.add_done_callback(print)   
 
@@ -176,25 +177,22 @@ class BaseEntertainer(Hookable):
         # THIS Comes form the Arkitekt Platform
 
     
-    async def entertain(self, bounced_provide: BouncedProvideMessage, from_arkitekt=False):
+    async def entertain(self, bounced_provide: BouncedProvideMessage, actorClass: Type[Actor], from_arkitekt=False):
         ''' Takes an instance of a pod, asks arnheim to activate it and accepts requests on it,
         cancel this task to unprovide your local implementatoin '''
         if from_arkitekt: logger.info("Entertainment invoked by Arkitekt")
-        actorClass = await self.get_actorclass_for_template(bounced_provide.data.template)
 
         provision_reference = bounced_provide.meta.reference # We register Actors unter its provision
-        actor = actorClass(bounced_provide, self.hostHelper)
+        actor = actorClass(self.connector)
 
         try:
-            # Try to reserve resources in its dependencies if there is any, if we fail we cancel everything
-            ok = await actor._on_provide()
             # Activate Provison , will return
             activation_task = asyncio.create_task(self.activateProvision(bounced_provide))
             activation_task.add_done_callback(print)
 
             self.provision_actor_map[provision_reference] = actor
             self.provision_actor_queue_map[provision_reference] = actor.queue
-            run_task = asyncio.create_task(actor.run())
+            run_task = asyncio.create_task(actor.run(bounced_provide))
             run_task.add_done_callback(partial(self.actor_cancelled, actor))
             self.provision_actor_run_map[provision_reference] = run_task
 
