@@ -1,18 +1,6 @@
 
-
-
-from asyncio.futures import Future
-from typing import Dict
-from bergen.messages.postman.provide.provide_done import ProvideDoneMessage
-from functools import partial
-from bergen.messages.postman.provide.bounced_provide import BouncedProvideMessage
-from bergen.entertainer.actor import HostHelper
-from bergen.messages.postman.assign.assign import AssignMessage
 from bergen.messages.base import MessageModel
 from bergen.messages.utils import expandToMessage
-from bergen.messages.host import ActivatePodMessage, DeActivatePodMessage
-from bergen.messages.postman.assign import BouncedAssignMessage, BouncedCancelAssignMessage, AssignCriticalMessage, AssignReturnMessage, AssignYieldsMessage, AssignProgressMessage
-from bergen.schema import Pod
 import json
 from bergen.entertainer.base import BaseEntertainer
 import logging
@@ -30,29 +18,10 @@ except ImportError:
 logger = logging.getLogger()
 
 
-class WebsocketHelper(HostHelper):
 
-    async def pass_yield(self, message: AssignMessage, value):
-        yield_message = AssignYieldsMessage(data={"yields": value}, meta={"extensions": message.meta.extensions, "reference": message.meta.reference})
-        await self.host.send_to_arkitekt(yield_message)
-
-    async def pass_progress(self, message: AssignMessage, value, percentage=None):
-        value = f'{percentage if percentage else "--"} : {value}'
-        progress_message = AssignProgressMessage(data={"message": value, "level": "INFO"}, meta={"extensions": message.meta.extensions, "reference": message.meta.reference})
-        await self.host.send_to_arkitekt(progress_message)
-
-    async def pass_result(self,message: AssignMessage, value):
-        return_message = AssignReturnMessage(data={"returns": value}, meta={"extensions": message.meta.extensions, "reference": message.meta.reference})
-        await self.host.send_to_arkitekt(return_message)
-
-    async def pass_exception(self, message: AssignMessage, exception):
-        error_message = AssignCriticalMessage(data={"message": str(exception)}, meta={"extensions": message.meta.extensions, "reference": message.meta.reference})
-        print("Sending to arkitekt")
-        await self.host.send_to_arkitekt(error_message)
 
 
 class WebsocketEntertainer(BaseEntertainer):
-    helperClass = WebsocketHelper
     ''' Is a mixin for Our Bergen '''
 
     def __init__(self, host= None, port= None, protocol=None, auto_reconnect=True, auth: dict= None, **kwargs) -> None:
@@ -143,10 +112,8 @@ class WebsocketEntertainer(BaseEntertainer):
     async def consumer(self):
         logger.warning(" [x] Awaiting Entertaining Calls")
         async for message in self.connection:
-            logger.info(f"Incoming {message}")
             await self.incoming_queue.put(message)
 
-
     async def producer(self):
         while True:
             message = await self.outgoing_queue.get()
@@ -158,19 +125,11 @@ class WebsocketEntertainer(BaseEntertainer):
         await self.outgoing_queue.put(message)
 
 
-    async def send_to_arkitekt(self, message: MessageModel):
-        await self.outgoing_queue.put(message)
-       
-
-    def raise_exception(self, future: Future):
-        if future.exception():
-            raise future.exception()
-
     async def workers(self):
         while True:
             message_str = await self.incoming_queue.get()
             message = expandToMessage(json.loads(message_str))
-            logger.info("Received Assignation")
+            logger.info(f"Received Message {message}")
             await self.on_message(message)
             self.incoming_queue.task_done()
 
