@@ -25,5 +25,7 @@ class DataPointType(str, Enum):
 
 
 
-class TYPENAMES(str, Enum):
-    MODELPORTTYPE = "ModelPortType"
\ No newline at end of file
+class PortTypes(str, Enum):
+    MODEL_ARG_PORT = "ModelArgPort"
+    MODEL_KWARG_PORT = "ModelKwargPort"
+    MODEL_RETURN_PORT = "ModelReturnPort"
\ No newline at end of file
