@@ -10,7 +10,7 @@ from pydantic.main import BaseModel
 from bergen.constants import OFFER_GQL
 import logging
 import asyncio
-from bergen.models import Node
+from bergen.models import Node, Template
 import inspect
 from bergen.messages import *
 
@@ -65,9 +65,7 @@ class BaseProvider(Hookable):
             assert callable(function_or_actor) or issubclass(function_or_actor, Actor), "Please only decorate functions or subclasses of Actor"
             # TODO: Check if function has same parameters as node
 
-            template = OFFER_GQL.run(
-            ward=self.client.main_ward,
-            variables= {
+            template = Template.objects.update_or_create(**{
                 "node": node.id,
                 "params": implementation_details,
                 "policy": policy.dict()
