@@ -18,6 +18,9 @@ DataModel = ForwardRef("DataModel")
 
 
 
+
+
+
 class AssignationParams(ArnheimObject):
     provider: Optional[str]
 
@@ -39,9 +42,20 @@ class User(ArnheimModel):
     class Meta:
         identifier = "user"
 
+class App(ArnheimModel):
+    client_id: Optional[str]
+    name: Optional[str]
+    grant_type: Optional[str]
+
+    class Meta:
+        identifier = "app"
+
 class DataPoint(ArnheimModel):
+    app: Optional[App]
+    user: Optional[User]
     type: Optional[str]
     name: Optional[str]
+    needsNegotiation: Optional[bool]
     inward: Optional[str]
     outward: Optional[str]
     port: Optional[int]
@@ -75,7 +89,6 @@ class EntertainerSettings(ArnheimObject):
     kwargs: Optional[dict]
 
 class Transcript(ArnheimObject):
-    extensions: Optional[Any]
     postman: Optional[PostmanSettings]
     host: Optional[EntertainerSettings]
     provider: Optional[ProviderSettings]
